@@ -12,7 +12,7 @@ class monday_endpoints:
         self.complexity_retries = 0
         self.real_data_dict = []
         if logging_file:
-            logging.basicConfig(filename=logging_file, encoding="utf-8",level=logging.debug)
+            logging.basicConfig(filename=logging_file, encoding="utf-8",level=0)
     
     def make_request(self, body, get_raw_request=False):
         """
